@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,7 +20,8 @@
 #include "abstractimapsettingscheckjob.h"
 
 AbstractImapSettingsCheckJob::AbstractImapSettingsCheckJob(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      mSettingsWereImported(false)
 {
 
 }
@@ -29,3 +30,10 @@ AbstractImapSettingsCheckJob::~AbstractImapSettingsCheckJob()
 {
 
 }
+
+void AbstractImapSettingsCheckJob::checkNoSettingsImported()
+{
+    if (!mSettingsWereImported) {
+        Q_EMIT noSettingsImported(name());
+    }
+}
