@@ -21,17 +21,27 @@
 #define ABSTRACTIMAPSETTINGSCHECKJOB_H
 
 #include <QObject>
+#include "../../sieveeditorutil.h"
+#include "libsieveeditor_private_export.h"
 
-class AbstractImapSettingsCheckJob : public QObject
+class LIBSIEVEEDITOR_TESTS_EXPORT AbstractImapSettingsCheckJob : public QObject
 {
     Q_OBJECT
 public:
-    explicit AbstractImapSettingsCheckJob(QObject *parent = Q_NULLPTR);
+    explicit AbstractImapSettingsCheckJob(QObject *parent = nullptr);
     ~AbstractImapSettingsCheckJob();
     virtual void start() = 0;
 
     virtual bool settingsCanBeImported() const = 0;
     virtual QString name() const = 0;
+
+Q_SIGNALS:
+    void importSetting(const QString &name, const SieveEditorUtil::SieveServerConfig &settings);
+    void noSettingsImported(const QString &name);
+
+protected:
+    void checkNoSettingsImported();
+    bool mSettingsWereImported;
 };
 
 #endif // ABSTRACTIMAPSETTINGSCHECKJOB_H
