@@ -21,18 +21,22 @@
 #define IMPORTIMAPSETTINGSAKONADICHECKJOB_H
 
 #include "abstractimapsettingscheckjob.h"
-
-class ImportImapSettingsAkonadiCheckJob : public AbstractImapSettingsCheckJob
+#include "libsieveeditor_private_export.h"
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingsAkonadiCheckJob : public AbstractImapSettingsCheckJob
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingsAkonadiCheckJob(QObject *parent = Q_NULLPTR);
+    explicit ImportImapSettingsAkonadiCheckJob(QObject *parent = nullptr);
     ~ImportImapSettingsAkonadiCheckJob();
 
     void start() Q_DECL_OVERRIDE;
 
     bool settingsCanBeImported() const Q_DECL_OVERRIDE;
     QString name() const Q_DECL_OVERRIDE;
+
+private:
+    inline bool resourceCanHaveSieveSupport(const QString &filename) const;
+    bool importSettings(const QString &directory, const QString &filename);
 };
 
 #endif // IMPORTIMAPSETTINGSAKONADICHECKJOB_H
