@@ -21,17 +21,21 @@
 #define IMPORTIMAPSETTINGSTHUNDERBIRDCHECKJOB_H
 
 #include "abstractimapsettingscheckjob.h"
-
-class ImportImapSettingsThunderbirdCheckJob : public AbstractImapSettingsCheckJob
+#include "libsieveeditor_private_export.h"
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingsThunderbirdCheckJob : public AbstractImapSettingsCheckJob
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingsThunderbirdCheckJob(QObject *parent = Q_NULLPTR);
+    explicit ImportImapSettingsThunderbirdCheckJob(QObject *parent = nullptr);
     ~ImportImapSettingsThunderbirdCheckJob();
 
     void start() Q_DECL_OVERRIDE;
     bool settingsCanBeImported() const Q_DECL_OVERRIDE;
     QString name() const Q_DECL_OVERRIDE;
+private:
+    bool importSettings(const QString &directory, const QString &filename);
+    QMap<QString, QString> listProfile(QString &currentProfile, const QString &defaultSettingPath);
+    QString defaultPath() const;
 };
 
 #endif // IMPORTIMAPSETTINGSTHUNDERBIRDCHECKJOB_H
