@@ -19,17 +19,17 @@
 
 #ifndef IMPORTIMAPSETTINGFINISHPAGE_H
 #define IMPORTIMAPSETTINGFINISHPAGE_H
-
+#include "libsieveeditor_private_export.h"
 #include <QWidget>
 class QTextEdit;
-class ImportImapSettingFinishPage : public QWidget
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingFinishPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingFinishPage(QWidget *parent = Q_NULLPTR);
+    explicit ImportImapSettingFinishPage(QWidget *parent = nullptr);
     ~ImportImapSettingFinishPage();
 
-    void setImportResult(const QString &result);
+    void addSummary(const QString &name);
 
 private:
     QTextEdit *mTextEdit;
