@@ -21,12 +21,13 @@
 #define IMPORTIMAPSETTINGNOFOUNDPAGE_H
 
 #include <QWidget>
+#include "libsieveeditor_private_export.h"
 
-class ImportImapSettingNoFoundPage : public QWidget
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingNoFoundPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingNoFoundPage(QWidget *parent = Q_NULLPTR);
+    explicit ImportImapSettingNoFoundPage(QWidget *parent = nullptr);
     ~ImportImapSettingNoFoundPage();
 };
 
