@@ -21,18 +21,34 @@
 #define IMPORTIMAPSETTINGPROGRESSPAGE_H
 
 #include <QWidget>
+#include <QMap>
+#include "sieveeditorutil.h"
+#include "libsieveeditor_private_export.h"
+
 class QTextEdit;
-class ImportImapSettingProgressPage : public QWidget
+class AbstractImapSettingsCheckJob;
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingProgressPage : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingProgressPage(QWidget *parent = Q_NULLPTR);
+    explicit ImportImapSettingProgressPage(QWidget *parent = nullptr);
     ~ImportImapSettingProgressPage();
     void addProgressInfo(const QString &str);
     void setSelectedPrograms(const QStringList &programs);
+    void setListCheckJob(const QMap<QString, AbstractImapSettingsCheckJob *> &listCheckJob);
+
+    void start();
+
+Q_SIGNALS:
+    void finished();
+    void noSettingsImported(const QString &name);
+
 private:
+    void slotImportSettingsDone(const QString &name, const SieveEditorUtil::SieveServerConfig &settings);
     QStringList mSelectedPrograms;
     QTextEdit *mProgressTextEdit;
+    QMap<QString, AbstractImapSettingsCheckJob *> mListCheckJob;
+    bool mSettingsFound;
 };
 
 #endif // IMPORTIMAPSETTINGPROGRESSPAGE_H
