@@ -20,14 +20,15 @@
 #ifndef IMPORTIMAPSETTINGSEARCHPAGE_H
 #define IMPORTIMAPSETTINGSEARCHPAGE_H
 
+#include "libsieveeditor_private_export.h"
 #include <QWidget>
 class QListWidget;
 
-class ImportImapSettingSearchPage : public QWidget
+class LIBSIEVEEDITOR_TESTS_EXPORT ImportImapSettingSearchPage : public QWidget
 {
     Q_OBJECT
 public:
-    ImportImapSettingSearchPage(QWidget *parent = Q_NULLPTR);
+    ImportImapSettingSearchPage(QWidget *parent = nullptr);
     ~ImportImapSettingSearchPage();
 
     void setProgramList(const QStringList &lst);
