@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -28,6 +28,9 @@
 #include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <PimCommon/PimUtil>
+
+#include <QPushButton>
 
 ImportImapSettingWizard::ImportImapSettingWizard(QWidget *parent)
     : KAssistantDialog(parent)
@@ -44,6 +47,8 @@ ImportImapSettingWizard::ImportImapSettingWizard(QWidget *parent)
 
     mProgressPage = new ImportImapSettingProgressPage(this);
     mProgressPageItem = new KPageWidgetItem(mProgressPage, i18n("Import in Progress..."));
+    connect(mProgressPage, &ImportImapSettingProgressPage::finished, this, &ImportImapSettingWizard::slotFinishImportData);
+    connect(mProgressPage, &ImportImapSettingProgressPage::noSettingsImported, this, &ImportImapSettingWizard::slotNoSettingsFound);
     addPage(mProgressPageItem);
 
     mFinishPage = new ImportImapSettingFinishPage(this);
@@ -52,6 +57,7 @@ ImportImapSettingWizard::ImportImapSettingWizard(QWidget *parent)
 
     readConfig();
     initializeWizard();
+    connect(button(QDialogButtonBox::Help), &QPushButton::clicked, this, &ImportImapSettingWizard::slotHelpClicked);
 }
 
 ImportImapSettingWizard::~ImportImapSettingWizard()
@@ -61,47 +67,51 @@ ImportImapSettingWizard::~ImportImapSettingWizard()
 
 void ImportImapSettingWizard::initializeWizard()
 {
-    ImportImapSettingsThunderbirdCheckJob *thjob = new ImportImapSettingsThunderbirdCheckJob(this);
-    thjob->name();
-    mListCheckJob.insert(thjob->name(), thjob);
-    ImportImapSettingsAkonadiCheckJob *akonadiJob = new ImportImapSettingsAkonadiCheckJob(this);
-    mListCheckJob.insert(akonadiJob->name(), akonadiJob);
-
     bool hasSettingToImport = false;
-    Q_FOREACH (AbstractImapSettingsCheckJob *job, mListCheckJob.values()) {
-        if (job->settingsCanBeImported()) {
-            hasSettingToImport = true;
-            break;
-        }
+    ImportImapSettingsThunderbirdCheckJob *thjob = new ImportImapSettingsThunderbirdCheckJob(this);
+    if (thjob->settingsCanBeImported()) {
+        mListCheckJob.insert(thjob->name(), thjob);
+        hasSettingToImport = true;
+    } else {
+        delete thjob;
     }
+    ImportImapSettingsAkonadiCheckJob *akonadiJob = new ImportImapSettingsAkonadiCheckJob(this);
+    if (akonadiJob->settingsCanBeImported()) {
+        mListCheckJob.insert(akonadiJob->name(), akonadiJob);
+        hasSettingToImport = true;
+    } else {
+        delete akonadiJob;
+    }
+
     if (hasSettingToImport) {
+        //Initialize list
+        mSearchPage->setProgramList(mListCheckJob.keys());
         setAppropriate(mNoFoundPageItem, false);
         setAppropriate(mSearchPageItem, true);
         setAppropriate(mProgressPageItem, true);
         setAppropriate(mFinishPageItem, true);
         setCurrentPage(mSearchPageItem);
     } else {
-        setCurrentPage(mNoFoundPageItem);
         setAppropriate(mNoFoundPageItem, true);
         setAppropriate(mSearchPageItem, false);
         setAppropriate(mProgressPageItem, false);
         setAppropriate(mFinishPageItem, false);
+        setCurrentPage(mNoFoundPageItem);
     }
 }
 
 void ImportImapSettingWizard::next()
 {
-    if (currentPage() == mNoFoundPageItem) {
-        if (isAppropriate(mSearchPageItem)) {
-            mSearchPage->setProgramList(mListCheckJob.keys());
-        }
-    } else if (currentPage() == mSearchPageItem) {
+    if (currentPage() == mSearchPageItem) {
         const QStringList programs = mSearchPage->selectedPrograms();
         if (programs.isEmpty()) {
             //Go to end
             setAppropriate(mProgressPageItem, false);
         } else {
+            mProgressPage->setListCheckJob(mListCheckJob);
             mProgressPage->setSelectedPrograms(programs);
+            //Start importation
+            mProgressPage->start();
         }
     }
     KAssistantDialog::next();
@@ -123,3 +133,18 @@ void ImportImapSettingWizard::writeConfig()
     group.sync();
 }
 
+void ImportImapSettingWizard::slotFinishImportData()
+{
+    setAppropriate(mFinishPageItem, true);
+    setAppropriate(mSearchPageItem, false);
+}
+
+void ImportImapSettingWizard::slotNoSettingsFound(const QString &name)
+{
+    mFinishPage->addSummary(name);
+}
+
+void ImportImapSettingWizard::slotHelpClicked()
+{
+    PimCommon::Util::invokeHelp(QStringLiteral("sieveeditor/index.html"));
+}
