@@ -21,6 +21,7 @@
 #define IMPORTIMAPSETTINGWIZARD_H
 
 #include <KAssistantDialog>
+#include "libsieveeditor_export.h"
 
 class ImportImapSettingSearchPage;
 class ImportImapSettingNoFoundPage;
@@ -28,11 +29,11 @@ class ImportImapSettingProgressPage;
 class ImportImapSettingFinishPage;
 class KPageWidgetItem;
 class AbstractImapSettingsCheckJob;
-class ImportImapSettingWizard : public KAssistantDialog
+class LIBSIEVEEDITOR_EXPORT ImportImapSettingWizard : public KAssistantDialog
 {
     Q_OBJECT
 public:
-    explicit ImportImapSettingWizard(QWidget *parent = Q_NULLPTR);
+    explicit ImportImapSettingWizard(QWidget *parent = nullptr);
     ~ImportImapSettingWizard();
 
     void next() Q_DECL_OVERRIDE;
@@ -41,6 +42,9 @@ private:
     void readConfig();
     void writeConfig();
     void initializeWizard();
+    void slotHelpClicked();
+    void slotFinishImportData();
+    void slotNoSettingsFound(const QString &name);
     QMap<QString, AbstractImapSettingsCheckJob *> mListCheckJob;
 
     ImportImapSettingSearchPage *mSearchPage;
