@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -85,10 +85,11 @@ void SieveEditorPageWidget::setIsNewScript(bool isNewScript)
     mIsNewScript = isNewScript;
 }
 
-void SieveEditorPageWidget::loadScript(const QUrl &url, const QStringList &capabilities)
+void SieveEditorPageWidget::loadScript(const QUrl &url, const QStringList &capabilities, const KSieveUi::SieveImapAccountSettings &sieveImapAccountSettings)
 {
     mCurrentURL = url;
     mSieveEditorWidget->setSieveCapabilities(capabilities);
+    mSieveEditorWidget->setSieveImapAccountSettings(sieveImapAccountSettings);
     mSieveEditorWidget->setReadOnly(true);
     mSieveEditorWidget->wordWrap(SieveEditorGlobalConfig::self()->wrapText());
     KManageSieve::SieveJob *job = KManageSieve::SieveJob::get(url);
@@ -142,10 +143,10 @@ void SieveEditorPageWidget::slotPutResult(KManageSieve::SieveJob *job, bool succ
     } else {
         const QString msg = job->errorString();
         if (msg.isEmpty())
-            KMessageBox::error(Q_NULLPTR, i18n("Uploading the Sieve script failed.\n"
-                                               "The server responded:\n%1", msg, i18n("Sieve Error")));
+            KMessageBox::error(nullptr, i18n("Uploading the Sieve script failed.\n"
+                                             "The server responded:\n%1", msg, i18n("Sieve Error")));
         else {
-            KMessageBox::error(Q_NULLPTR, msg, i18n("Sieve Error"));
+            KMessageBox::error(nullptr, msg, i18n("Sieve Error"));
         }
     }
 }
